@@ -107,7 +107,7 @@ quint32 WindowSystem::lastInputSerial(QWindow *window)
 
 WId WindowSystem::activeWindow()
 {
-    qCDebug(KWAYLAND_KWS) << "This plugin does not support virtual desktops";
+    qCDebug(KWAYLAND_KWS) << "This plugin does not support querying the active window";
     return 0;
 }
 
@@ -145,12 +145,14 @@ int WindowSystem::currentDesktop()
     return 0;
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 101)
 void WindowSystem::demandAttention(WId win, bool set)
 {
     Q_UNUSED(win)
     Q_UNUSED(set)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support demanding attention";
 }
+#endif
 
 QString WindowSystem::desktopName(int desktop)
 {
@@ -296,6 +298,7 @@ void WindowSystem::setStrut(WId win, int left, int right, int top, int bottom)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support window struts";
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 101)
 void WindowSystem::setIcons(WId win, const QPixmap &icon, const QPixmap &miniIcon)
 {
     Q_UNUSED(win)
@@ -303,6 +306,7 @@ void WindowSystem::setIcons(WId win, const QPixmap &icon, const QPixmap &miniIco
     Q_UNUSED(miniIcon)
     qCDebug(KWAYLAND_KWS) << "This plugin does not support setting window icons";
 }
+#endif
 
 void WindowSystem::setOnActivities(WId win, const QStringList &activities)
 {
